# 「能不能好好说话？」 的 CLI 版本

基于[@itorr](https://github.com/itorr)的[能不能好好说话？](https://github.com/itorr/nbnhhsh)，命令行版本


## 安装(Python3.6+)

pip3 install hhsh

## 例子

```shell

hhsh "我 tmd 这到底是什么，人人都在说 yyds, 啊啊啊"

```

## 致谢
- [能不能好好说话？](https://github.com/itorr/nbnhhsh):  拼音首字母缩写翻译工具